==> ejc-proequipmentcorp-impl-3.0.0-20221124.024157-181-sources.jar: com/ejianc/business/proequipmentcorppur/purchase/bean/RecordPurchaseContractDetailEntity.java <==
package com.ejianc.business.proequipmentcorppur.purchase.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 设备采购合同-记录表-机械设备明细表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proequipmentcorp_purchase_record_detailed")
public class RecordPurchaseContractDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="tree_index")
    private String treeIndex; // 序号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="equipment_type")
    private String equipmentType; // 设备类别
    @TableField(value="equipment_name")
    private String equipmentName; // 设备名称
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="company")
    private String company; // 单位
    @TableField(value="purchase_num")
    private Long purchaseNum; // 采购数量
    @TableField(value="purchase_price")
    private BigDecimal purchasePrice; // 采购单价
    @TableField(value="purchase_amount")
    private BigDecimal purchaseAmount; // 采购金额
    @TableField(value="estimate_amortize_mny")
    private BigDecimal estimateAmortizeMny; // 预估摊销金额
    @TableField(value="tax_rate")
    private BigDecimal taxRate; // 税率
    @TableField(value="purchase_pricet_no_tax")
    private BigDecimal purchasePricetNoTax; // 采购单价(无税)
    @TableField(value="purchase_amount_no_tax")
    private BigDecimal purchaseAmountNoTax; // 采购金额(无税)
    @TableField(value="tax_mny")
    private BigDecimal taxMny; // 税额
    @TableField(value="acceptance_quantity")
    private Integer acceptanceQuantity; // 验收数量
    @TableField(value="manufacturer")
    private String manufacturer; // 生产厂家
    @TableField(value="detail_memo")
    private String detailMemo; // 备注
    @TableField(value="source_id")
    private Long sourceId; // 来源数据Id
    @TableField(value="source_type")
    private String sourceType; // 来源类型
    @TableField(value="contract_id")
    private Long contractId; // 所属合同Id
    @TableField(value="record_id")
    private Long recordId; // 记录表id
    @TableField(value="change_id")
    private Long changeId; // 变更表主键
    @TableField(value="src_tbl_id")
    private Long srcTblId; // 来源子表主键
    @TableField(value="parent_id")
    private Long parentId; // 父ID
    @TableField(value="change_type")
    private String changeType; // 变更类型
    @TableField(value="doc_category_id")
    private Long docCategoryId; // 档案分类id
    @TableField(value="doc_id")
    private Long docId; // 档案Id
    @TableField(value="equipment_code")
    private String equipmentCode; // 设备编码
    @TableField(value="sign_num")
    private BigDecimal signNum;
    @TableField(value="source_price")
    private BigDecimal sourcePrice;
    @TableField(value="source_tax_price")
    private BigDecimal sourceTaxPrice;
    @TableField(value="init_num")
    private BigDecimal initNum;

    public BigDecimal getSignNum() {
        return signNum;
    }

    public void setSignNum(BigDecimal signNum) {
        this.signNum = signNum;
    }

    public BigDecimal getSourcePrice() {
        return sourcePrice;
    }

    public void setSourcePrice(BigDecimal sourcePrice) {
        this.sourcePrice = sourcePrice;
    }

    public BigDecimal getSourceTaxPrice() {
        return sourceTaxPrice;
    }

    public void setSourceTaxPrice(BigDecimal sourceTaxPrice) {
        this.sourceTaxPrice = sourceTaxPrice;
    }

    public BigDecimal getInitNum() {
        return initNum;
    }

    public void setInitNum(BigDecimal initNum) {
        this.initNum = initNum;
    }

    public String getTreeIndex() {
        return treeIndex;
    }

    public void setTreeIndex(String treeIndex) {
        this.treeIndex = treeIndex;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getEquipmentType() {
        return equipmentType;
    }

    public void setEquipmentType(String equipmentType) {
        this.equipmentType = equipmentType;
    }
    public String getEquipmentName() {
        return equipmentName;
    }

    public void setEquipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getCompany() {
        return company;
    }

    public void setCompany(String company) {
        this.company = company;
    }
    public Long getPurchaseNum() {
        return purchaseNum;
    }

    public void setPurchaseNum(Long purchaseNum) {
        this.purchaseNum = purchaseNum;
    }
    public BigDecimal getPurchasePrice() {
        return purchasePrice;
    }

    public void setPurchasePrice(BigDecimal purchasePrice) {
        this.purchasePrice = purchasePrice;
    }
    public BigDecimal getPurchaseAmount() {
        return purchaseAmount;
    }

    public void setPurchaseAmount(BigDecimal purchaseAmount) {
        this.purchaseAmount = purchaseAmount;
    }
    public BigDecimal getEstimateAmortizeMny() {
        return estimateAmortizeMny;
    }

    public void setEstimateAmortizeMny(BigDecimal estimateAmortizeMny) {
        this.estimateAmortizeMny = estimateAmortizeMny;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getPurchasePricetNoTax() {
        return purchasePricetNoTax;
    }

    public void setPurchasePricetNoTax(BigDecimal purchasePricetNoTax) {
        this.purchasePricetNoTax = purchasePricetNoTax;
    }
    public BigDecimal getPurchaseAmountNoTax() {
        return purchaseAmountNoTax;
    }

    public void setPurchaseAmountNoTax(BigDecimal purchaseAmountNoTax) {
        this.purchaseAmountNoTax = purchaseAmountNoTax;
    }
    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }
    public Integer getAcceptanceQuantity() {
        return acceptanceQuantity;
    }

    public void setAcceptanceQuantity(Integer acceptanceQuantity) {
        this.acceptanceQuantity = acceptanceQuantity;
    }
    public String getManufacturer() {
        return manufacturer;
    }

    public void setManufacturer(String manufacturer) {
        this.manufacturer = manufacturer;
    }
    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Long getRecordId() {
        return recordId;
    }

    public void setRecordId(Long recordId) {
        this.recordId = recordId;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public Long getSrcTblId() {
        return srcTblId;
    }

    public void setSrcTblId(Long srcTblId) {
        this.srcTblId = srcTblId;
    }
    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }
    public String getChangeType() {
        return changeType;
    }

    public void setChangeType(String changeType) {
        this.changeType = changeType;
    }
    public Long getDocCategoryId() {
        return docCategoryId;
    }

    public void setDocCategoryId(Long docCategoryId) {
        this.docCategoryId = docCategoryId;
    }
    public Long getDocId() {
        return docId;
    }

    public void setDocId(Long docId) {
        this.docId = docId;
    }

    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }
}

==> ejc-proequipmentcorp-impl-3.0.0-20251013.062057-516-sources.jar: com/ejianc/business/proequipmentcorppur/purchase/bean/RecordPurchaseContractDetailEntity.java <==
package com.ejianc.business.proequipmentcorppur.purchase.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 设备采购合同-记录表-机械设备明细表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proequipmentcorp_purchase_record_detailed")
public class RecordPurchaseContractDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="tree_index")
    private String treeIndex; // 序号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="equipment_type")
    private String equipmentType; // 设备类别
    @TableField(value="equipment_name")
    private String equipmentName; // 设备名称
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="company")
    private String company; // 单位
    @TableField(value="purchase_num")
    private Long purchaseNum; // 采购数量
    @TableField(value="purchase_price")
    private BigDecimal purchasePrice; // 采购单价
    @TableField(value="purchase_amount")
    private BigDecimal purchaseAmount; // 采购金额
    @TableField(value="estimate_amortize_mny")
    private BigDecimal estimateAmortizeMny; // 预估摊销金额
    @TableField(value="tax_rate")
    private BigDecimal taxRate; // 税率
    @TableField(value="purchase_pricet_no_tax")
    private BigDecimal purchasePricetNoTax; // 采购单价(无税)
    @TableField(value="purchase_amount_no_tax")
    private BigDecimal purchaseAmountNoTax; // 采购金额(无税)
    @TableField(value="tax_mny")
    private BigDecimal taxMny; // 税额
    @TableField(value="acceptance_quantity")
    private Integer acceptanceQuantity; // 验收数量
    @TableField(value="manufacturer")
    private String manufacturer; // 生产厂家
    @TableField(value="detail_memo")
    private String detailMemo; // 备注
    @TableField(value="source_id")
    private Long sourceId; // 来源数据Id
    @TableField(value="source_type")
    private String sourceType; // 来源类型
    @TableField(value="contract_id")
    private Long contractId; // 所属合同Id
    @TableField(value="record_id")
    private Long recordId; // 记录表id
    @TableField(value="change_id")
    private Long changeId; // 变更表主键
    @TableField(value="src_tbl_id")
    private Long srcTblId; // 来源子表主键
    @TableField(value="parent_id")
    private Long parentId; // 父ID
    @TableField(value="change_type")
    private String changeType; // 变更类型
    @TableField(value="doc_category_id")
    private Long docCategoryId; // 档案分类id
    @TableField(value="doc_id")
    private Long docId; // 档案Id
    @TableField(value="equipment_code")
    private String equipmentCode; // 设备编码
    @TableField(value="sign_num")
    private BigDecimal signNum;
    @TableField(value="source_price")
    private BigDecimal sourcePrice;
    @TableField(value="source_tax_price")
    private BigDecimal sourceTaxPrice;
    @TableField(value="init_num")
    private BigDecimal initNum;


    @TableField(value="history_price_area")
    private String historyPriceArea;//历史价格区间（无税）
    @TableField(value="history_tax_price_area")
    private String historyTaxPriceArea;//历史价格区间（含税）
    @TableField(value="guide_price_area")
    private String guidePriceArea; // 公司指导价区间（无税）
    @TableField(value="guide_tax_price_area")
    private String guideTaxPriceArea; // 公司指导价区间（含税）


    public String getHistoryPriceArea() {
        return historyPriceArea;
    }

    public void setHistoryPriceArea(String historyPriceArea) {
        this.historyPriceArea = historyPriceArea;
    }

    public String getHistoryTaxPriceArea() {
        return historyTaxPriceArea;
    }

    public void setHistoryTaxPriceArea(String historyTaxPriceArea) {
        this.historyTaxPriceArea = historyTaxPriceArea;
    }

    public String getGuidePriceArea() {
        return guidePriceArea;
    }

    public void setGuidePriceArea(String guidePriceArea) {
        this.guidePriceArea = guidePriceArea;
    }

    public String getGuideTaxPriceArea() {
        return guideTaxPriceArea;
    }

    public void setGuideTaxPriceArea(String guideTaxPriceArea) {
        this.guideTaxPriceArea = guideTaxPriceArea;
    }

    public BigDecimal getSignNum() {
        return signNum;
    }

    public void setSignNum(BigDecimal signNum) {
        this.signNum = signNum;
    }

    public BigDecimal getSourcePrice() {
        return sourcePrice;
    }

    public void setSourcePrice(BigDecimal sourcePrice) {
        this.sourcePrice = sourcePrice;
    }

    public BigDecimal getSourceTaxPrice() {
        return sourceTaxPrice;
    }

    public void setSourceTaxPrice(BigDecimal sourceTaxPrice) {
        this.sourceTaxPrice = sourceTaxPrice;
    }

    public BigDecimal getInitNum() {
        return initNum;
    }

    public void setInitNum(BigDecimal initNum) {
        this.initNum = initNum;
    }

    public String getTreeIndex() {
        return treeIndex;
    }

    public void setTreeIndex(String treeIndex) {
        this.treeIndex = treeIndex;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getEquipmentType() {
        return equipmentType;
    }

    public void setEquipmentType(String equipmentType) {
        this.equipmentType = equipmentType;
    }
    public String getEquipmentName() {
        return equipmentName;
    }

    public void setEquipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getCompany() {
        return company;
    }

    public void setCompany(String company) {
        this.company = company;
    }
    public Long getPurchaseNum() {
        return purchaseNum;
    }

    public void setPurchaseNum(Long purchaseNum) {
        this.purchaseNum = purchaseNum;
    }
    public BigDecimal getPurchasePrice() {
        return purchasePrice;
    }

    public void setPurchasePrice(BigDecimal purchasePrice) {
        this.purchasePrice = purchasePrice;
    }
    public BigDecimal getPurchaseAmount() {
        return purchaseAmount;
    }

    public void setPurchaseAmount(BigDecimal purchaseAmount) {
        this.purchaseAmount = purchaseAmount;
    }
    public BigDecimal getEstimateAmortizeMny() {
        return estimateAmortizeMny;
    }

    public void setEstimateAmortizeMny(BigDecimal estimateAmortizeMny) {
        this.estimateAmortizeMny = estimateAmortizeMny;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getPurchasePricetNoTax() {
        return purchasePricetNoTax;
    }

    public void setPurchasePricetNoTax(BigDecimal purchasePricetNoTax) {
        this.purchasePricetNoTax = purchasePricetNoTax;
    }
    public BigDecimal getPurchaseAmountNoTax() {
        return purchaseAmountNoTax;
    }

    public void setPurchaseAmountNoTax(BigDecimal purchaseAmountNoTax) {
        this.purchaseAmountNoTax = purchaseAmountNoTax;
    }
    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }
    public Integer getAcceptanceQuantity() {
        return acceptanceQuantity;
    }

    public void setAcceptanceQuantity(Integer acceptanceQuantity) {
        this.acceptanceQuantity = acceptanceQuantity;
    }
    public String getManufacturer() {
        return manufacturer;
    }

    public void setManufacturer(String manufacturer) {
        this.manufacturer = manufacturer;
    }
    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Long getRecordId() {
        return recordId;
    }

    public void setRecordId(Long recordId) {
        this.recordId = recordId;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public Long getSrcTblId() {
        return srcTblId;
    }

    public void setSrcTblId(Long srcTblId) {
        this.srcTblId = srcTblId;
    }
    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }
    public String getChangeType() {
        return changeType;
    }

    public void setChangeType(String changeType) {
        this.changeType = changeType;
    }
    public Long getDocCategoryId() {
        return docCategoryId;
    }

    public void setDocCategoryId(Long docCategoryId) {
        this.docCategoryId = docCategoryId;
    }
    public Long getDocId() {
        return docId;
    }

    public void setDocId(Long docId) {
        this.docId = docId;
    }

    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }
}
